package edu.uchicago.cs.java.finalproject.tronscan.examples;

import java.io.File;

public class CurrentWorkingDirectory {
	public static void main(String args[]) {
		File directory = new File(".");
		try {
			
			System.out.println("Best method to get current directory is System.getProperty(\"user.dir\"): " + 
					 System.getProperty("user.dir"));
			
			
			System.out.println("You can also instantitae a File and get its current directory's canonical path: "
					+ directory.getCanonicalPath());
			
			System.out.println("or the file's current directory's absolute  path: "
					+ directory.getAbsolutePath());
			


			
		} catch (Exception e) {
			System.out.println("Exceptione is =" + e.getMessage());
		}
	}
}