package edu.uchicago.cs.java.finalproject.tronscan;
//a somewhat generic class to hold transitions for rows and cols and determine the 
public class Pair {

	 private int nA;
	 private int nB;
	public Pair(int nA, int nB) {
		super();
		this.nA = nA;
		this.nB = nB;
	}
	
	public int getnA() {
		return this.nA;
	}
	public void setnA(int nA) {
		this.nA = nA;
	}
	public int getnB() {
		return this.nB;
	}
	public void setnB(int nB) {
		this.nB = nB;
	}
	 
	 public int getDiff(){
		 
		
		 return  Math.abs(nA - nB);
	 }
	 
}