package edu.uchicago.cs.java.finalproject.tronscan;

import java.awt.image.BufferedImage;

// ===============================================
// ==to be implemented 
// ===============================================


public class Exam {
	
	private Answer[] ansAnswers = new Answer[100];
	private BufferedImage bufImg;
	
	//other fields here
	
	
	

}
